use lib "t/testlib";
use TestAuto;

use strict;
use warnings;

use SPVM 'TestCase::NativeAPI';
use SPVM 'TestCase::NativeAPISrc';
